//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Item/SpecularBeamInclinationItem.h
//! @brief     Declares the class SpecularBeamInclinationItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_ITEM_SPECULARBEAMINCLINATIONITEM_H
#define BORNAGAIN_GUI_MODEL_ITEM_SPECULARBEAMINCLINATIONITEM_H

#include "GUI/Model/Item/BeamDistributionItem.h"
#include "GUI/Model/Item/PointwiseAxisItem.h"

//! BeamInclinationAxisItem contains inclination angle axis for specular/off-specular
//! simulations and also provides distribution functionality.
//! Considering distribution, differs from BeamInclinationAngleItem
//! by any distribution mean value being always zero.

class SpecularBeamInclinationItem : public BeamDistributionItem {
public:
    explicit SpecularBeamInclinationItem(const InstrumentItem* owningInstrument);

    void serialize(Serializer& s) override;
    double scaleFactor() const override;

    //! The currently selected axis
    BasicAxisItem* alphaAxis() const;

    //! True when a pointwise axis was defined. It still is no necessarily the selected axis!
    bool pointwiseAlphaAxisDefined() const;

    void selectUniformAxis();
    void selectPointwiseAxis();

    void initUniformAxis(const IAxis& axis);
    void initPointwiseAxis(const IAxis& axis, QString units);

private:
    std::unique_ptr<BasicAxisItem> m_uniformAlphaAxis;
    std::unique_ptr<PointwiseAxisItem> m_pointwiseAlphaAxis;
    bool m_currentAxisIsUniformAxis;

    const InstrumentItem* m_owningInstrument;
};

#endif // BORNAGAIN_GUI_MODEL_ITEM_SPECULARBEAMINCLINATIONITEM_H
