//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Item/SphericalDetectorItem.h
//! @brief     Defines class SphericalDetectorItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_ITEM_SPHERICALDETECTORITEM_H
#define BORNAGAIN_GUI_MODEL_ITEM_SPHERICALDETECTORITEM_H

#include "GUI/Model/Item/DetectorItems.h"
#include "GUI/Model/Types/AxisProperty.h"

class SphericalDetectorItem : public DetectorItem {
public:
    SphericalDetectorItem();

    void serialize(Serializer& s) override;

    int xSize() const override;
    int ySize() const override;
    void setXSize(size_t nx) override;
    void setYSize(size_t ny) override;

    double axesToDomainUnitsFactor() const override;

    AXIS_PROPERTY(phiAxis);
    AXIS_PROPERTY(alphaAxis);

protected:
    std::unique_ptr<IDetector2D> createDomainDetector() const override;
};

#endif // BORNAGAIN_GUI_MODEL_ITEM_SPHERICALDETECTORITEM_H
